# remirepo/fedora spec file for php-zumba-json-serializer
#
# SPDX-FileCopyrightText:  Copyright 2024 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%bcond_without       tests

%global gh_commit    1b1b2302d46692f317021ee4b9cc06b1311b7333
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zumba
%global gh_project   json-serializer
%global ns_vendor    Zumba
%global ns_project   JsonSerializer
%global major        %nil

Name:           php-%{gh_owner}-%{gh_project}%{major}
Version:        3.2.2
Release:        1%{?dist}
Summary:        Serialize PHP variables

License:        MIT
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{name}-%{version}-%{?gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
%if %{with tests}
# as we use phpunit10 by default
BuildRequires:  php(language) >= 8.1
BuildRequires:  php-date
BuildRequires:  php-json
BuildRequires:  php-mbstring
BuildRequires:  php-pcre
BuildRequires:  php-reflection
BuildRequires:  php-spl
# For tests, from composer.json "require-dev": {
#        "phpunit/phpunit": ">=8.0 <12.0"
%if 0%{?fedora} >= 40 || 0%{?rhel} >= 10
BuildRequires:  phpunit11
%global phpunit %{_bindir}/phpunit11
%else
BuildRequires:  phpunit10
%global phpunit %{_bindir}/phpunit10
%endif
%endif
# For autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": "^7.2 || ^8.0",
#        "ext-mbstring": "*"
Requires:       php(language) >= 7.2
Requires:       php-mbstring
# From phpcompatinfo report for 3.0.1
Requires:       php-json
Requires:       php-pcre
Requires:       php-reflection
Requires:       php-spl
# For generated autoloader
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}


%description
This is a library to serialize PHP variables in JSON format. It is similar
of the serialize() function in PHP, but the output is a string JSON encoded.
You can also unserialize the JSON generated by this tool and have you PHP
content back.

Autoloader: %{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
: Create autoloader
phpab --template fedora --output src/%{ns_project}/autoload.php src


%install
: Library
mkdir -p      %{buildroot}%{_datadir}/php/
cp -pr src    %{buildroot}%{_datadir}/php/%{ns_vendor}


%check
%if %{with tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('%{ns_vendor}\\%{ns_project}\\Test\\', dirname(__DIR__).'/tests');
EOF

ret=0
# ignore tests relying on SuperClosure (deprecated and removed from repo)
for cmdarg in "php %{phpunit}" "php81 %{_bindir}/phpunit10" php82 php83 php84; do
   if which $cmdarg; then
      set $cmdarg
      $1 ${2:-%{_bindir}/phpunit11} \
          --bootstrap vendor/autoload.php \
          --filter '^((?!(testAddSerializer|testGetPreferredSerializer|testSerialize|testUnserialize)).)*$' \
          --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc composer.json
%doc README.md
%dir %{_datadir}/php/%{ns_vendor}
     %{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}


%changelog
* Wed Dec 11 2024 Remi Collet <remi@remirepo.net> - 3.2.2-1
- update to 3.2.2
- re-license spec file to CECILL-2.1
- raise dependency on php 7.2
- switch to phpunit11

* Thu Oct 19 2023 Remi Collet <remi@remirepo.net> - 3.2.1-1
- update to 3.2.1

* Tue Sep 26 2023 Remi Collet <remi@remirepo.net> - 3.2.0-1
- update to 3.2.0
- sources from git snapshot
- switch to phpunit10

* Tue Jul 18 2023 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0

* Thu Dec  8 2022 Remi Collet <remi@remirepo.net> - 3.0.2-1
- update to 3.0.2 (no change)

* Thu Dec  9 2021 Remi Collet <remi@remirepo.net> - 3.0.1-1
- initial package
